pub fn install_hook_with_settings(
options: &mut ClientOptions,
settings: &SentrySettings,
)Expand description
Install the sentry hook on the provided client options.
This installs a before_send hook that increments sentry_events_total
and performs rate limiting, if configured. If a previous before_send
hook exists, it will be called after rate limiting has been applied.
Only unfiltered events are counted.
See the foundations-sentry crate-level docs for more information.